[gnome-shell] dnd: Reparent drag actor to the uiGroup rather then the stage



commit 64e7459d1c32bc66bc8ffcd38bc44990395c2e62
Author: Adel Gadllah <adel gadllah gmail com>
Date:   Thu Jun 30 20:57:37 2011 +0200

    dnd: Reparent drag actor to the uiGroup rather then the stage

 js/ui/dnd.js |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/js/ui/dnd.js b/js/ui/dnd.js
index 33f1501..c8c8d07 100644
--- a/js/ui/dnd.js
+++ b/js/ui/dnd.js
@@ -284,13 +284,13 @@ _Draggable.prototype = {
             this._dragOffsetY = actorStageY - this._dragStartY;
 
             // Set the actor's scale such that it will keep the same
             // transformed size when it's reparented to the stage
             let [scaledWidth, scaledHeight] = this.actor.get_transformed_size();
             this.actor.set_scale(scaledWidth / this.actor.width,
                                  scaledHeight / this.actor.height);
         }
 
-        this._dragActor.reparent(this.actor.get_stage());
+        this._dragActor.reparent(Main.uiGroup);
         this._dragActor.raise_top();
         Shell.util_set_hidden_from_pick(this._dragActor, true);
 
@@ -442,7 +442,7 @@ _Draggable.prototype = {
                         return true;
                     // If it accepted the drop without taking the actor,
                     // handle it ourselves.
-                    if (this._dragActor.get_parent() == this._dragActor.get_stage()) {
+                    if (this._dragActor.get_parent() == Main.uiGroup) {
                         if (this._restoreOnSuccess) {
                             this._restoreDragActor(event.get_time());
                             return true;
@@ -284,13 +284,13 @@ _Draggable.prototype = {
 
             // Set the actor's scale such that it will keep the same
-            // transformed size when it's reparented to the stage
+            // transformed size when it's reparented to the uiGroup
             let [scaledWidth, scaledHeight] = this.actor.get_transformed_size();
             this.actor.set_scale(scaledWidth / this.actor.width,



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]